flush_batch_physical

Function flush_batch_physical 

async fn flush_batch_physical(
    table_batches: &[TableBatch],
    total_row_count: usize,
    physical_table_name: &str,
    ctx: &QueryContextRef,
    partition_manager: &PartitionRuleManagerRef,
    node_manager: &NodeManagerRef,
    catalog_manager: &CatalogManagerRef,
    first_error: &mut Option<String>,
)
Attempts to flush all table batches by transforming them into the physical table format (sparse primary key encoding) and writing directly to the physical data regions.

This is the only flush path. Any failure in resolving or transforming the physical flush inputs is recorded as flush failure and reported to waiters.